@@ -3,16 +3,6 @@
 
 using namespace std;
 
-void runidir(double *u, double &theta, double &phi)
-{
-    phi=2.0*PI*runif(0.0,1.0);
-    theta=acos(2.0*runif(0.0,1.0)-1.0);
-
-    u[0]=cos(phi)*sin(theta);
-    u[1]=sin(phi)*sin(theta);
-    u[2]=cos(theta);
-}
-
 void vectorRotation(double *u, double *w, double *mu)
 {
 	double sphi, cphi, sth;
@@ -27,29 +17,53 @@ void vectorRotation(double *u, double *w, double *mu)
 	}
 	else
 	{
-		if(mu[2]>0) {u[0]=w[0]; u[1]=w[1]; u[2]=w[2];}
-		if(mu[2]<0) {u[0]=-w[0]; u[1]=-w[1]; u[2]=-w[2];}
+		if(mu[2]>0) {
+		  u[0]=w[0];
+		  u[1]=w[1];
+		  u[2]=w[2];
+		}
+		if(mu[2]<0) {
+		  u[0]=-w[0];
+		  u[1]=-w[1];
+		  u[2]=-w[2];
+		}
 	}
 
 }
 
-void rVonMisesFisher(double *u, double *mu, double kappa, double &phi)
+void runidir(double *u, double &theta, double &phi)
 {
-    double v[2], s, w[3];
     phi = 2.0*PI*runif(0.0,1.0);
-    v[0] = cos(phi); v[1] = sin(phi);
-    w[2] = log(exp(-kappa)+(exp(kappa)-exp(-kappa))*runif(0.0,1.0))/kappa;
-    s = sqrt(1-w[2]*w[2]);
-    w[0] = s*v[0];
-    w[1] = s*v[1];
+    theta = acos(2.0*runif(0.0,1.0)-1.0);
+
+    u[0] = cos(phi)*sin(theta);
+    u[1] = sin(phi)*sin(theta);
+    u[2] = cos(theta);
+}
+
+
+void rVonMisesFisher(double *u, double *mu, double kappa, double &theta, double &phi)
+{
+    double w[3];
+
+    phi = 2.0*PI*runif(0.0,1.0);
+    //w[2] = log(exp(-kappa)+(exp(kappa)-exp(-kappa))*runif(0.0,1.0))/kappa;
+    //theta = acos(w[2]);
+
+    theta = acos(log(exp(-kappa)+(exp(kappa)-exp(-kappa))*runif(0.0,1.0))/kappa);
+    w[2] = cos(theta);
+    double s = sqrt(1-w[2]*w[2]);
+
+    w[0] = s*cos(phi);
+    w[1] = s*sin(phi);
 
     vectorRotation(u,w,mu);
 }
 
 void rOhserSchladitz(double *u, double *mu, double kappa, double &theta, double &phi)
 {
-    double q,w[3];
-    phi = 2.0*M_PI*runif(0.0,1.0);
+    double q, w[3];
+    phi = 2.0*M_PI*runif(0.0,1.0);  // 0.0; /* DEBUG */
     q = runif(0.0,1.0);
     theta = acos((1-2*q)/sqrt(kappa*kappa-(1-2*q)*(1-2*q)*(kappa*kappa-1)));
 
@@ -59,8 +73,3 @@ void rOhserSchladitz(double *u, double *mu, double kappa, double &theta, double
 
     vectorRotation(u,w,mu);
 }
-
-double scalarProduct(double *x, double *y)
-{
-    return x[0]*y[0]+x[1]*y[1]+x[2]*y[2];
-}
